function err = L2Err_BFE(Mesh,u,QuadRule,FHandle,varargin)

  % Intialize constants
  
  nElements = size(Mesh.Elements,1);
  nGauss = size(QuadRule.w,1);
  
  % Compute discretization error

  err = 0;
  for i = 1:nElements
       
    % Extract vertex numbers
    
    vidx = Mesh.Elements(i,:);
    
    % Extract vertices
      
    P1 = Mesh.Coordinates(vidx(1),:);
    P2 = Mesh.Coordinates(vidx(2),:);
    P3 = Mesh.Coordinates(vidx(3),:);
    P4 = Mesh.Coordinates(vidx(4),:);

    for j = 1:nGauss

      % Compute element mapping PhiK and matrix M

      grad_N = grad_shap_BFE(QuadRule.x(j,:));  
      N = shap_BFE(QuadRule.x(j,:));
      M(1,:) = P1(1)*grad_N(1:2)+P2(1)*grad_N(3:4) + ...
                    P3(1)*grad_N(5:6)+P4(1)*grad_N(7:8);
      M(2,:) = P1(2)*grad_N(1:2)+P2(2)*grad_N(3:4) + ...
                    P3(2)*grad_N(5:6)+P4(2)*grad_N(7:8);
      det_M = abs(det(M));

      % Compute point x

      x = N(1)*P1+N(2)*P2+N(3)*P3+N(4)*P4;
  
      % Evaluate solutions
      
      u_EX = FHandle(x,varargin{:});
      u_FE = u(vidx(1))*N(1)+u(vidx(2))*N(2) + ...
             u(vidx(3))*N(3)+u(vidx(4))*N(4);
      
      % Add in error
      
      err = err + QuadRule.w(j)*abs(u_EX-u_FE).^2*det_M;

    end
      
  end

  err = sqrt(err);
  
return
