function floc = Load_BFE(Vertices,f,QuadRule)

  % Initialize constants

  nGauss = size(QuadRule.w,1);

  % Preallocate memory

  floc = zeros(4,1);

  % Extract vertices
    
  P1 = Vertices(1,:);
  P2 = Vertices(2,:);
  P3 = Vertices(3,:);
  P4 = Vertices(4,:);

  for j = 1:nGauss

    % Compute element mapping PhiK and matrix M

    N = shap_BFE(QuadRule.x(j,:));
    grad_N = grad_shap_BFE(QuadRule.x(j,:));
    M(1,:) = P1(1)*grad_N(1:2)+P2(1)*grad_N(3:4) + ...
                  P3(1)*grad_N(5:6)+P4(1)*grad_N(7:8);
    M(2,:) = P1(2)*grad_N(1:2)+P2(2)*grad_N(3:4) + ...
                  P3(2)*grad_N(5:6)+P4(2)*grad_N(7:8);
    det_M = abs(det(M));

    % Compute point x

    x = N(1)*P1+N(2)*P2+N(3)*P3+N(4)*P4;

    % Compute load data

    FVal = f(x);

    % Add contributions to element load vector

    floc(1) = floc(1) + QuadRule.w(j)*FVal*N(1).*det_M; 
    floc(2) = floc(2) + QuadRule.w(j)*FVal*N(2).*det_M;
    floc(3) = floc(3) + QuadRule.w(j)*FVal*N(3).*det_M; 
    floc(4) = floc(4) + QuadRule.w(j)*FVal*N(4).*det_M;

  end

return
