function u = Parb_Evl_BFE(Mesh,u0,FHandle,T,Nsteps)

  % Initialize quadrature rules
  QuadRule = TProd(gauleg(0,1,4));

  % Compute matrices
  M = assemMat_BFE(Mesh,@MASS_BFE,QuadRule);
  A = assemMat_BFE(Mesh,@STIMA_Lapl_BFE,QuadRule);

  % Compute time steps
  dt = T/Nsteps;
    
  % Compute matrices
  S1 = M + dt*A;
  S2 = M;

  % Isolate free nodes
  [temp, FreeDofs] = assemDir_BFE(Mesh,-1, @(x,varargin) zeros(size(x,1),1));
    
  % Start time stepping
  for i = 1:Nsteps
        
    % Assemble load vector
    L_new = assemLoad_BFE(Mesh,QuadRule,@(x,varargin)FHandle(x,i*dt));
    rhs = S2*u0 + dt*L_new;
        
    % Solve the linear system
    u_new = zeros(size(u0));
    u_new(FreeDofs) = S1(FreeDofs,FreeDofs)\rhs(FreeDofs);
        
    % Update vectors
    u0 = u_new;

  end

  u = u0;

end
