% Run script for bilinear finite elements on a quadrilateral mesh 

clear all
close all

% Initialize constants

% Number of red refinement steps
NREFS = 4;
%Final time
T = 0.1;
% Right-hand side source term
F_HANDLE   = @(x,varargin) zeros(size(x,1),1);
% Initial data
U0_HANDLE  = @(x,varargin) sin(pi*x(:,1)).*sin(pi*x(:,2));
% Exact solution
UEX_HANDLE = @(x,t,varargin) exp(-2*pi^2*t)*sin(pi*x(:,1)).*sin(pi*x(:,2));
      
% Initialize mesh
Mesh = load_Mesh('Coord_Square.dat','Elem_Square.dat');
Mesh = add_Edges(Mesh);
Loc = get_BdEdges(Mesh);
Mesh.BdFlags = zeros(size(Mesh.Edges,1),1);
Mesh.BdFlags(Loc) = -1;
Mesh.ElemFlag = zeros(size(Mesh.Elements,1),1);

% Initialize quadrature rules
QuadRule = TProd(gauleg(0,1,4));

% Do NREFS uniform refinement steps
L2Err = zeros(1,NREFS);
nDofs = zeros(1,NREFS);
  
for j = 1:NREFS
      
    % refine mesh
    Mesh = refine_REG(Mesh);

    % Number of time steps
    NSTEPS = 200;

    % Compute matrices
    M = assemMat_BFE(Mesh,@MASS_BFE,QuadRule);

    % Compute initial data
    u_old = assemLoad_BFE(Mesh,QuadRule,U0_HANDLE);
    u_old = M\u_old;

    % Run timestepping
    u_new = Parb_Evl_BFE(Mesh, u_old, F_HANDLE, T, NSTEPS);
   
    % Compute L2 error  at time T  
    L2Err(j) = L2Err_BFE(Mesh,u_new,QuadRule,UEX_HANDLE,T);
    nDofs(j) = size(Mesh.Coordinates,1);

end
 
% Plot out discretization error against number of dofs and add slope triangles
  
figure(2);
h = axes;
plot(nDofs,L2Err,'ko-')
grid('on');
set(gca,'XScale','log','YScale','log');
set(h,'FontSize',14);
xlabel('Dofs [log]');
ylabel('Discretization error [log]');
 
p = polyfit(log(nDofs),log(L2Err),1);
add_Slope(gca,'NorthEast',p(1));
